@@ -427,12 +427,26 @@ t_testbed_add_device_errors(UMockdevTestbedFixture * fixture, gconstpointer data
     syspath = umockdev_testbed_add_device(fixture->testbed, "usb", "usb1", NULL,
 					  /* attributes */
 					  "idVendor", "0815", "idProduct", NULL, NULL);
-    g_log_remove_handler(NULL, log_handler);
     g_assert(syspath);
     g_assert_cmpint(errors.counter, ==, 2);
     g_assert_cmpint(errors.last_level & G_LOG_LEVEL_WARNING, !=, 0);
     g_assert(strstr(errors.last_message, "idProduct") != NULL);
 
+    /* duplicate symlinks are a bug in the device description, but should not crash */
+    g_assert(umockdev_testbed_add_from_string(fixture->testbed,
+					      "P: /devices/target\nN: target\nS: link\n"
+					      "E: SUBSYSTEM=foo\nE: DEVNAME=/dev/target\n"
+					      "A: dev=1:4\n", NULL));
+
+    g_assert(umockdev_testbed_add_from_string(fixture->testbed,
+					      "P: /devices/other\nN: other\nS: link\n"
+					      "E: SUBSYSTEM=foo\nE: DEVNAME=/dev/other\n"
+					      "A: dev=1:5\n", NULL));
+    g_assert_cmpint(errors.counter, ==, 3);
+    g_assert_cmpint(errors.last_level & G_LOG_LEVEL_WARNING, !=, 0);
+    g_assert(strstr(errors.last_message, "File exists") != NULL);
+
+    g_log_remove_handler(NULL, log_handler);
 }
 
 static void
@@ -904,8 +918,8 @@ t_testbed_add_from_string(UMockdevTestbedFixture * fixture, gconstpointer data)
     g_assert_cmpstr(g_udev_device_get_sysfs_attr(device, "dev2color"), ==, "green");
     g_assert_cmpstr(g_udev_device_get_property(device, "DEV2COLOR"), ==, "GREEN");
     g_assert(g_file_test("/sys/devices/dev2/subsystem", G_FILE_TEST_IS_SYMLINK));
-    g_assert(g_file_test("/sys/devices/dev2/subsystem/dev2", G_FILE_TEST_IS_SYMLINK));
-    g_assert(g_file_test("/sys/devices/dev2/subsystem/dev2/dev2color", G_FILE_TEST_IS_REGULAR));
+    g_assert(g_file_test("/sys/devices/dev2/subsystem/devices/dev2", G_FILE_TEST_IS_SYMLINK));
+    g_assert(g_file_test("/sys/devices/dev2/subsystem/devices/dev2/dev2color", G_FILE_TEST_IS_REGULAR));
 
     /* check subdev1 */
     subdev = g_udev_client_query_by_sysfs_path(client, "/sys/devices/dev2/subdev1");
