@@ -190,12 +190,19 @@ A: simple_attr=1
             self.assertEqual(f.read(), b'\x41\xFF\x00\x05\xFF\x00')
 
     def test_add_from_string_errors(self):
+        try:
+            # python 3.2+
+            assertRaisesRegex = self.assertRaisesRegex
+        except AttributeError:
+            # python 2 && python < 3.2
+            assertRaisesRegex = self.assertRaisesRegexp
+
         # does not start with P:
-        with self.assertRaisesRegex(GLib.GError, 'must start with.*P:') as cm:
+        with assertRaisesRegex(GLib.GError, 'must start with.*P:') as cm:
             self.testbed.add_from_string ('E: SIMPLE_PROP=1\n')
 
         # no value
-        with self.assertRaisesRegex(GLib.GError, 'malformed attribute') as cm:
+        with assertRaisesRegex(GLib.GError, 'malformed attribute') as cm:
             self.testbed.add_from_string ('P: /devices/dev1\nE: SIMPLE_PROP\n')
 
 unittest.main(testRunner=unittest.TextTestRunner(stream=sys.stdout, verbosity=2))
